==> tecfy_corev2_package-1.0.1.tar.gz: lib/controllers/account/login.controller.dart <==
part of tecfy_corev2_client_package;

class LoginController extends BaseController {
  bool isLocked = false;

  /// form key
  late GlobalKey formKey;

  /// username text controller
  late TextEditingController usernameController;

  /// password text controller
  late TextEditingController passwordController;

  /// account service
  late AccountService service;

  /// user name validator
  String usernameValidator(String? v) =>
      v == null || v.isEmpty ? 'Please Enter your Email or Username' : '';

  /// password validator
  String passwordValidator(String? v) =>
      v == null || v.isEmpty ? 'Please Enter your Password' : '';

  /// login page controller
  LoginController(State<StatefulWidget> state) : super(state) {
    formKey = GlobalKey<FormState>();
    usernameController = TextEditingController();
    passwordController = TextEditingController();
    service = AccountService();
    isLocked = ConfigService.getValueBool('LoginExpired');
    usernameController.text = LocalConfigService.user?.username ?? '';

    if (isLocked && usernameController.text.isEmpty) {
      Future.delayed(Duration(seconds: 1)).then((_) {
        AccountService.signout(context, true);
      });
    }
  }

  Future onLogout() {
    return AccountService.signout(context);
  }

  /// login and goto main page
  Future onLogin() async {
    var result = await service.login(
        usernameController.text.trim(), passwordController.text.trim());

    if (result.success) {
      await AccountService.init(context);
    } else {
      print('================== Login result============');
      print(result);
      print(result.success);
      print(result.message);
      print(result.innerError);
      if (result.errorCodeString == 'ClientVersionNotSupported') {
        TecfyCoreApp.mustUpgrade = true;
        AppLocale.languageStreamController.add(LocalConfigService.language);
        return;
      }
      showMessage(result.message ?? "Error", MessageType.error);
    }
  }

  /// show contact us page
  contactUs() async {
    Widget getField(label, value) {
      return Row(crossAxisAlignment: CrossAxisAlignment.start, children: [
        Text('${AppLocale.translate(label)}:',
            style: TextStyle(fontWeight: FontWeight.bold)),
        SizedBox(width: 10),
        Expanded(child: Text(value, maxLines: 5)),
      ]);
    }

    await AppNavigator.showAppDialog(
      context,
      (c) => Material(
        type: MaterialType.transparency,
        child: Center(
          child: Container(
            width: 300,
            height: 300,
            child: Card(
                margin: EdgeInsets.all(10),
                child: Padding(
                    padding: EdgeInsets.all(10),
                    child: Column(children: [
                      getField('Website', 'https://tecfy.co'),
                      getField('Email', 'info@tecfy.co'),
                      getField('Address',
                          'Office 3 Building 3 on Hafez Ibrahem and Babel Street, Alsharq District, Port Said, Egypt'),
                      Expanded(child: Container()),
                      TextButton(
                          child: Text(AppLocale.translate('Close'),
                              style: TextStyle(color: ThemeService.subColor)),
                          onPressed: () => Navigator.of(context).pop())
                    ]))),
          ),
        ),
      ),
    );
  }
}

==> tecfy_corev2_package-1.1.51.tar.gz: lib/controllers/account/login.controller.dart <==
part of tecfy_corev2_client_package;

class LoginController extends BaseController {
  bool isLocked = false;

  /// form key
  late GlobalKey formKey;

  /// username text controller
  late TextEditingController usernameController;

  /// password text controller
  late TextEditingController passwordController;

  /// account service
  late AccountService service;

  /// user name validator
  String usernameValidator(String? v) =>
      v == null || v.isEmpty ? 'Please Enter your Email or Username' : '';

  /// password validator
  String passwordValidator(String? v) =>
      v == null || v.isEmpty ? 'Please Enter your Password' : '';

  /// login page controller
  LoginController(State<StatefulWidget> state) : super(state) {
    formKey = GlobalKey<FormState>();
    usernameController = TextEditingController();
    passwordController = TextEditingController();
    service = AccountService();
    isLocked = ConfigService.getValueBool('LoginExpired');
    usernameController.text = LocalConfigService.user?.email ?? '';

    if (isLocked && usernameController.text.isEmpty) {
      Future.delayed(Duration(seconds: 1)).then((_) {
        AccountService.signout(context, true);
      });
    }
  }

  Future onLogout() {
    return AccountService.signout(context);
  }

  /// login and goto main page
  Future onLogin() async {
    var result = await service.login(
        usernameController.text.trim(), passwordController.text.trim());

    if (result.success) {
      await AccountService.init(context);
    } else {
      print('================== Login result============');
      print(result);
      print(result.success);
      print(result.message);
      print(result.innerError);
      if (result.errorCodeString == 'ClientVersionNotSupported') {
        TecfyCoreApp.mustUpgrade = true;
        AppLocale.languageStreamController.add(LocalConfigService.language);
        return;
      }
      showMessage(result.message ?? "Error", MessageType.error);
    }
  }

  /// show contact us page
  contactUs() async {
    Widget getField(label, value) {
      return Row(crossAxisAlignment: CrossAxisAlignment.start, children: [
        Text('${AppLocale.translate(label)}:',
            style: TextStyle(fontWeight: FontWeight.bold)),
        SizedBox(width: 10),
        Expanded(child: Text(value, maxLines: 5)),
      ]);
    }

    await AppNavigator.showAppDialog(
      context,
      (c) => Material(
        type: MaterialType.transparency,
        child: Center(
          child: Container(
            width: 300,
            height: 300,
            child: Card(
                margin: EdgeInsets.all(10),
                child: Padding(
                    padding: EdgeInsets.all(10),
                    child: Column(children: [
                      getField('Website', 'https://tecfy.co'),
                      getField('Email', 'info@tecfy.co'),
                      getField('Address',
                          'Office 3 Building 3 on Hafez Ibrahem and Babel Street, Alsharq District, Port Said, Egypt'),
                      Expanded(child: Container()),
                      TextButton(
                          child: Text(AppLocale.translate('Close'),
                              style: TextStyle(color: ThemeService.subColor)),
                          onPressed: () => Navigator.of(context).pop())
                    ]))),
          ),
        ),
      ),
    );
  }
}
